from downward.reports import PlanningReport

from collections import defaultdict

class DifferentCoverageDomainReport(PlanningReport):
    def __init__(self, algo_to_print = {}, domain_to_print = {}, **kwargs):
        PlanningReport.__init__(self, **kwargs)
        self.algo_to_print = algo_to_print
        self.domain_to_print = domain_to_print

    def get_text(self):
        set_dd = lambda: defaultdict(set)
        tasks_solved_by_domain_by_algo = defaultdict(set_dd)
        domains = set()
        algo_to_coverage = defaultdict(int)
        domains_to_num_tasks = defaultdict(int)
        for (domain, problem), runs in self.problem_runs.items():
            domains.add(domain)
            for run in runs:
                if run['coverage']:
                    tasks_solved_by_domain_by_algo[run['domain']][run['algorithm']].add(run['problem'])
                    algo_to_coverage[run['algorithm']] += 1

        boring_domains = set()
        coverage_boring_domains = 0
        for domain in domains:
            reference_solved_tasks = tasks_solved_by_domain_by_algo[domain][self.algorithms[0]]
            if all(tasks_solved_by_domain_by_algo[domain][algo] == reference_solved_tasks for algo in self.algorithms):
                boring_domains.add(domain)
                coverage_boring_domains += len(reference_solved_tasks)
        # print(boring_domains)
        # print(coverage_boring_domains)
        print(sorted(domains - boring_domains))
        num_boring_tasks = 0
        for domain in boring_domains:
            num_boring_tasks += len(self.domains[domain])
        print("Number of problems in equal domains {}".format(num_boring_tasks))
        num_interesting_tasks = 0
        for domain in domains - boring_domains:
            num_interesting_tasks += len(self.domains[domain])
        print("Number of problems in interesting domains {}".format(num_interesting_tasks))

        def turn_list_into_table_row(line):
            values = [elem for elem in line if isinstance(elem, int)]
            max_val = None
            if values:
                max_val = max(values)
            result = ''
            for index, value in enumerate(line):
                if value == max_val:
                    result += '\\textbf{{{}}}'.format(value)
                else:
                    result += '{}'.format(value)
                if index == len(line) - 1:
                    result += ' \\\\'
                else:
                    result += ' & '
            return result

        def format_algo(algo):
            if algo in self.algo_to_print:
                return self.algo_to_print[algo]
            return algo

        def format_domain(domain):
            if domain in self.domain_to_print:
                return self.domain_to_print[domain]
            return domain

        lines = []

        header_line = ['']
        for algo in self.algorithms:
            header_line.append(format_algo(algo))
        lines.append(turn_list_into_table_row(header_line))

        # domain coverage for interesting domains
        for domain in sorted(domains - boring_domains):
            line = []
            line.append(format_domain(domain))
            for algo in self.algorithms:
                line.append(len(tasks_solved_by_domain_by_algo[domain][algo]))
            lines.append(turn_list_into_table_row(line))

        # total coverage of interesting domains
        line = []
        line.append('sum')
        for algo in self.algorithms:
            line.append(algo_to_coverage[algo] - coverage_boring_domains)
        lines.append(turn_list_into_table_row(line))

        # total coverage of boring domains
        line = []
        line.append('other domains')
        for algo in self.algorithms:
            line.append(coverage_boring_domains)
        lines.append(turn_list_into_table_row(line))

        # total coverage
        line = []
        line.append('total')
        for algo in self.algorithms:
            line.append(algo_to_coverage[algo])
        lines.append(turn_list_into_table_row(line))

        return '\n'.join(lines)
