#! /usr/bin/env python
# -*- coding: utf-8 -*-

# import itertools
# import numpy
import os

from collections import defaultdict

from downward.experiment import FastDownwardExperiment
# from downward.reports import PlanningReport
from downward.reports.absolute import AbsoluteReport
from downward.reports.compare import ComparativeReport
from downward.reports.scatter import ScatterPlotReport

from lab import tools
from lab.reports import Attribute, geometric_mean

from domain_comparison import DomainComparisonReport
from comparison import ComparisonReport
from different_coverage_domain_report import DifferentCoverageDomainReport

def get_script():
    """Get file name of main script."""
    return tools.get_script_path()


def get_script_dir():
    """Get directory of main script.

    Usually a relative directory (depends on how it was called by the user.)"""
    return os.path.dirname(get_script())

EXP_BASE_DIR = os.path.join(get_script_dir(), 'data')
exp = FastDownwardExperiment(path=os.path.join(EXP_BASE_DIR, 'paper-tables'))

REVISIONS = [
    'cae15baf9c83',
]

def remove_revision(run):
    algo = run['algorithm']
    for rev in REVISIONS:
        algo = algo.replace('{}-'.format(rev), '')
    run['algorithm'] = algo
    return run

def add_baseline_attributes(run):
    if run['algorithm'] == 'lmcut' or run['algorithm'] == 'blind' or run['algorithm'] == 'scp':
        assert run.get('ss_pruning_time') is None
        assert run.get('ss_pruning_ratio') is None
        run['ss_pruning_time'] = 0
    return run

def filter_wss(run):
    return 'wss' not in run['algorithm']

exp.add_fetcher(os.path.join(EXP_BASE_DIR, '2020-04-01-CRC-A-blind-eval'),filter=[remove_revision,add_baseline_attributes,filter_wss])
exp.add_fetcher(os.path.join(EXP_BASE_DIR, '2020-04-01-CRC-C-lmcut-eval'),filter=[remove_revision,add_baseline_attributes,filter_wss],merge=True)
exp.add_fetcher(os.path.join(EXP_BASE_DIR, '2020-04-01-CRC-D-scp-eval'),filter=[remove_revision,add_baseline_attributes,filter_wss],merge=True)

ss_successors_unpruned = Attribute("ss_successors_unpruned", absolute=True, min_wins=True)
ss_successors_pruned = Attribute("ss_successors_pruned", absolute=True, min_wins=True)
ss_pruning_ratio = Attribute("ss_pruning_ratio", absolute=True, min_wins=False)
ss_pruning_time = Attribute("ss_pruning_time", absolute=False, min_wins=True, function=geometric_mean)

## Overview reports

html_table_attributes = [
    'error',
    'run_dir',
    'coverage',
    # 'search_time',
    'total_time',
    'score_total_time',
    'generated',
    'expansions_until_last_jump',
    # ss_successors_unpruned,
    # ss_successors_pruned,
    ss_pruning_ratio,
    ss_pruning_time,
]

# blind

exp.add_report(
    AbsoluteReport(
        # attributes=['coverage'],
        attributes=html_table_attributes,
        format='html',
        filter_algorithm=[
            'blind',
            'blind-ec-min0.0',
            'blind-ec-mutex-min0.0',
            # 'blind-ec-wss-min0.0',
            'blind-simple-min0.0',
            'blind-simple-mutex-min0.0',
            # 'blind-simple-wss-min0.0',
            'blind-queue-fast_downward-min0.0',
            'blind-queue-fast_downward-mark-min0.0',
            'blind-queue-minimize_ss-min0.0',
            'blind-queue-minimize_ss-mark-min0.0',
            'blind-queue-dynamic_small-min0.0',
            'blind-queue-dynamic_small-mark-min0.0',
            'blind-queue-static_small-min0.0',
            'blind-queue-static_small-mark-min0.0',
            # 'blind-queue-wss-fast_downward-min0.0',
            # 'blind-queue-wss-fast_downward-mark-min0.0',
            # 'blind-queue-wss-minimize_ss-min0.0',
            # 'blind-queue-wss-minimize_ss-mark-min0.0',
            # 'blind-queue-wss-dynamic_small-min0.0',
            # 'blind-queue-wss-dynamic_small-mark-min0.0',
            # 'blind-queue-wss-static_small-min0.0',
            # 'blind-queue-wss-static_small-mark-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'blind.html'),
)

exp.add_report(
    AbsoluteReport(
        # attributes=['coverage'],
        attributes=html_table_attributes,
        format='html',
        filter_algorithm=[
            'blind',
            'blind-ec-min0.2',
            'blind-ec-mutex-min0.2',
            # 'blind-ec-wss-min0.2',
            'blind-simple-min0.2',
            'blind-simple-mutex-min0.2',
            # 'blind-simple-wss-min0.2',
            'blind-queue-fast_downward-min0.2',
            'blind-queue-fast_downward-mark-min0.2',
            'blind-queue-minimize_ss-min0.2',
            'blind-queue-minimize_ss-mark-min0.2',
            'blind-queue-dynamic_small-min0.2',
            'blind-queue-dynamic_small-mark-min0.2',
            'blind-queue-static_small-min0.2',
            'blind-queue-static_small-mark-min0.2',
            # 'blind-queue-wss-fast_downward-min0.2',
            # 'blind-queue-wss-fast_downward-mark-min0.2',
            # 'blind-queue-wss-minimize_ss-min0.2',
            # 'blind-queue-wss-minimize_ss-mark-min0.2',
            # 'blind-queue-wss-dynamic_small-min0.2',
            # 'blind-queue-wss-dynamic_small-mark-min0.2',
            # 'blind-queue-wss-static_small-min0.2',
            # 'blind-queue-wss-static_small-mark-min0.2',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'blind-min0.2.html'),
)

# lmcut

exp.add_report(
    AbsoluteReport(
        # attributes=['coverage'],
        attributes=html_table_attributes,
        format='html',
        filter_algorithm=[
            'lmcut',
            'lmcut-ec-min0.0',
            'lmcut-ec-mutex-min0.0',
            # 'lmcut-ec-wss-min0.0',
            'lmcut-simple-min0.0',
            'lmcut-simple-mutex-min0.0',
            # 'lmcut-simple-wss-min0.0',
            'lmcut-queue-fast_downward-min0.0',
            'lmcut-queue-fast_downward-mark-min0.0',
            'lmcut-queue-minimize_ss-min0.0',
            'lmcut-queue-minimize_ss-mark-min0.0',
            'lmcut-queue-dynamic_small-min0.0',
            'lmcut-queue-dynamic_small-mark-min0.0',
            'lmcut-queue-static_small-min0.0',
            'lmcut-queue-static_small-mark-min0.0',
            # 'lmcut-queue-wss-fast_downward-min0.0',
            # 'lmcut-queue-wss-fast_downward-mark-min0.0',
            # 'lmcut-queue-wss-minimize_ss-min0.0',
            # 'lmcut-queue-wss-minimize_ss-mark-min0.0',
            # 'lmcut-queue-wss-dynamic_small-min0.0',
            # 'lmcut-queue-wss-dynamic_small-mark-min0.0',
            # 'lmcut-queue-wss-static_small-min0.0',
            # 'lmcut-queue-wss-static_small-mark-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'lmcut.html'),
)

exp.add_report(
    AbsoluteReport(
        # attributes=['coverage'],
        attributes=html_table_attributes,
        format='html',
        filter_algorithm=[
            'lmcut',
            'lmcut-ec-min0.2',
            'lmcut-ec-mutex-min0.2',
            # 'lmcut-ec-wss-min0.2',
            'lmcut-simple-min0.2',
            'lmcut-simple-mutex-min0.2',
            # 'lmcut-simple-wss-min0.2',
            'lmcut-queue-fast_downward-min0.2',
            'lmcut-queue-fast_downward-mark-min0.2',
            'lmcut-queue-minimize_ss-min0.2',
            'lmcut-queue-minimize_ss-mark-min0.2',
            'lmcut-queue-dynamic_small-min0.2',
            'lmcut-queue-dynamic_small-mark-min0.2',
            'lmcut-queue-static_small-min0.2',
            'lmcut-queue-static_small-mark-min0.2',
            # 'lmcut-queue-wss-fast_downward-min0.2',
            # 'lmcut-queue-wss-fast_downward-mark-min0.2',
            # 'lmcut-queue-wss-minimize_ss-min0.2',
            # 'lmcut-queue-wss-minimize_ss-mark-min0.2',
            # 'lmcut-queue-wss-dynamic_small-min0.2',
            # 'lmcut-queue-wss-dynamic_small-mark-min0.2',
            # 'lmcut-queue-wss-static_small-min0.2',
            # 'lmcut-queue-wss-static_small-mark-min0.2',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'lmcut-min0.2.html'),
)

# scp

exp.add_report(
    AbsoluteReport(
        # attributes=['coverage'],
        attributes=html_table_attributes,
        format='html',
        filter_algorithm=[
            'scp',
            'scp-ec-min0.0',
            'scp-ec-mutex-min0.0',
            # 'scp-ec-wss-min0.0',
            'scp-simple-min0.0',
            'scp-simple-mutex-min0.0',
            # 'scp-simple-wss-min0.0',
            'scp-queue-fast_downward-min0.0',
            'scp-queue-fast_downward-mark-min0.0',
            'scp-queue-minimize_ss-min0.0',
            'scp-queue-minimize_ss-mark-min0.0',
            'scp-queue-dynamic_small-min0.0',
            'scp-queue-dynamic_small-mark-min0.0',
            'scp-queue-static_small-min0.0',
            'scp-queue-static_small-mark-min0.0',
            # 'scp-queue-wss-fast_downward-min0.0',
            # 'scp-queue-wss-fast_downward-mark-min0.0',
            # 'scp-queue-wss-minimize_ss-min0.0',
            # 'scp-queue-wss-minimize_ss-mark-min0.0',
            # 'scp-queue-wss-dynamic_small-min0.0',
            # 'scp-queue-wss-dynamic_small-mark-min0.0',
            # 'scp-queue-wss-static_small-min0.0',
            # 'scp-queue-wss-static_small-mark-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'scp.html'),
)

exp.add_report(
    AbsoluteReport(
        # attributes=['coverage'],
        attributes=html_table_attributes,
        format='html',
        filter_algorithm=[
            'scp',
            'scp-ec-min0.2',
            'scp-ec-mutex-min0.2',
            # 'scp-ec-wss-min0.2',
            'scp-simple-min0.2',
            'scp-simple-mutex-min0.2',
            # 'scp-simple-wss-min0.2',
            'scp-queue-fast_downward-min0.2',
            'scp-queue-fast_downward-mark-min0.2',
            'scp-queue-minimize_ss-min0.2',
            'scp-queue-minimize_ss-mark-min0.2',
            'scp-queue-dynamic_small-min0.2',
            'scp-queue-dynamic_small-mark-min0.2',
            'scp-queue-static_small-min0.2',
            'scp-queue-static_small-mark-min0.2',
            # 'scp-queue-wss-fast_downward-min0.2',
            # 'scp-queue-wss-fast_downward-mark-min0.2',
            # 'scp-queue-wss-minimize_ss-min0.2',
            # 'scp-queue-wss-minimize_ss-mark-min0.2',
            # 'scp-queue-wss-dynamic_small-min0.2',
            # 'scp-queue-wss-dynamic_small-mark-min0.2',
            # 'scp-queue-wss-static_small-min0.2',
            # 'scp-queue-wss-static_small-mark-min0.2',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'scp-min0.2.html'),
)

# exp.add_report(
    # ComparisonReport(
        # attributes=html_table_attributes,
        # format='html',
        # algorithm_pairs=[
            # ('blind-queue-fast_downward-min0.0', 'blind-queue-wss-fast_downward-min0.0'),
            # ('blind-queue-fast_downward-mark-min0.0', 'blind-queue-wss-fast_downward-mark-min0.0'),
            # ('blind-queue-minimize_ss-min0.0', 'blind-queue-wss-minimize_ss-min0.0'),
            # ('blind-queue-minimize_ss-mark-min0.0', 'blind-queue-wss-minimize_ss-mark-min0.0'),
        # ],
    # ),
    # outfile=os.path.join(exp.eval_dir, 'blind-wss-comp.html'),
# )

# exp.add_report(
    # ComparisonReport(
        # attributes=html_table_attributes,
        # format='html',
        # algorithm_pairs=[
            # ('lmcut-queue-fast_downward-min0.0', 'lmcut-queue-wss-fast_downward-min0.0'),
            # ('lmcut-queue-fast_downward-mark-min0.0', 'lmcut-queue-wss-fast_downward-mark-min0.0'),
            # ('lmcut-queue-minimize_ss-min0.0', 'lmcut-queue-wss-minimize_ss-min0.0'),
            # ('lmcut-queue-minimize_ss-mark-min0.0', 'lmcut-queue-wss-minimize_ss-mark-min0.0'),
        # ],
    # ),
    # outfile=os.path.join(exp.eval_dir, 'lmcut-wss-comp.html'),
# )

# exp.add_report(
    # ComparisonReport(
        # attributes=html_table_attributes,
        # format='html',
        # algorithm_pairs=[
            # ('scp-queue-fast_downward-min0.0', 'scp-queue-wss-fast_downward-min0.0'),
            # ('scp-queue-fast_downward-mark-min0.0', 'scp-queue-wss-fast_downward-mark-min0.0'),
            # ('scp-queue-minimize_ss-min0.0', 'scp-queue-wss-minimize_ss-min0.0'),
            # ('scp-queue-minimize_ss-mark-min0.0', 'scp-queue-wss-minimize_ss-mark-min0.0'),
        # ],
    # ),
    # outfile=os.path.join(exp.eval_dir, 'scp-wss-comp.html'),
# )

## Latex reports

latex_table_attributes = [
    # 'cost',
    'coverage',
    # 'error',
    # 'evaluations_until_last_jump',
    'expansions_until_last_jump',
    # 'generated_until_last_jump',
    # 'initial_h_value',
    # 'memory',
    # 'run_dir',
    # 'search_time',
    'total_time',
    # 'unsolvable',
    # 'unsolvable_incomplete',
    # 'evaluations',
    # 'expansions',
    # 'generated',
    # 'score_evaluations',
    # 'score_expansions',
    # 'score_memory',
    # 'score_search_time',
    # 'score_total_time',

    # ss_successors_unpruned,
    # ss_successors_pruned,
    ss_pruning_ratio,
    ss_pruning_time,
]

unsolvable = ['miconic-fulladl:f21-3.pddl', 'miconic-fulladl:f30-2.pddl', 'mystery:prob04.pddl', 'mystery:prob05.pddl', 'mystery:prob07.pddl', 'mystery:prob08.pddl', 'mystery:prob12.pddl', 'mystery:prob16.pddl', 'mystery:prob18.pddl', 'mystery:prob21.pddl', 'mystery:prob22.pddl', 'mystery:prob23.pddl', 'mystery:prob24.pddl']

def filter_unsolvable_tasks(run):
    return "{}:{}".format(run['domain'], run['problem']) not in unsolvable

domain_groups_optimal = {
'agricola-opt18-strips': 'agricola',
'airport': 'airport', # identity
'assembly': 'assembly', # identity
'barman-opt11-strips': 'barman',
'barman-opt14-strips': 'barman',
'blocks': 'blocks', # identity
'caldera-opt18-adl': 'caldera',
'caldera-split-opt18-adl': 'caldera-split',
'cavediving-14-adl': 'cavediving',
'childsnack-opt14-strips': 'childsnack',
'citycar-opt14-adl': 'citycar',
'data-network-opt18-strips': 'data-network',
'depot': 'depot', # identity
'driverlog': 'driverlog', # identity
'elevators-opt08-strips': 'elevators',
'elevators-opt11-strips': 'elevators',
'floortile-opt11-strips': 'floortile',
'floortile-opt14-strips': 'floortile',
'freecell': 'freecell', # identity
'ged-opt14-strips': 'ged',
'grid': 'grid', # identity
'gripper': 'gripper', # identity
'hiking-opt14-strips': 'hiking',
'logistics00': 'logistics',
'logistics98': 'logistics',
'maintenance-opt14-adl': 'maintenance',
'miconic': 'miconic', # identity
'miconic-fulladl': 'miconic',
'miconic-simpleadl': 'miconic',
'movie': 'movie', # identity
'mprime': 'mprime', # identity
'mystery': 'mystery', # identity
'nomystery-opt11-strips': 'nomystery',
'nurikabe-opt18-adl': 'nurikabe',
'openstacks': 'openstacks', # identity
'openstacks-opt08-adl': 'openstacks',
'openstacks-opt08-strips': 'openstacks',
'openstacks-opt11-strips': 'openstacks',
'openstacks-opt14-strips': 'openstacks',
'openstacks-strips': 'openstacks',
'optical-telegraphs': 'optical-telegraphs', # identity
'organic-synthesis-opt18-strips': 'organic-synthesis',
'organic-synthesis-split-opt18-strips': 'organic-synthesis-split',
'parcprinter-08-strips': 'parcprinter',
'parcprinter-opt11-strips': 'parcprinter',
'parking-opt11-strips': 'parking',
'parking-opt14-strips': 'parking',
'pathways': 'pathways', # identity
'pathways-noneg': 'pathways',
'pegsol-08-strips': 'pegsol',
'pegsol-opt11-strips': 'pegsol',
'petri-net-alignment-opt18-strips': 'petri-net-alignment',
'philosophers': 'philosophers', # identity
'pipesworld-notankage': 'pipesworld-notankage', # pipesworld?
'pipesworld-tankage': 'pipesworld-tankage', # pipesworld?
'psr-large': 'psr',
'psr-middle': 'psr',
'psr-small': 'psr',
'rovers': 'rovers', # identity
'satellite': 'satellite', # identity
'scanalyzer-08-strips': 'scanalyzer',
'scanalyzer-opt11-strips': 'scanalyzer',
'schedule': 'schedule', # identity
'settlers-opt18-adl': 'settlers',
'snake-opt18-strips': 'snake',
'sokoban-opt08-strips': 'sokoban',
'sokoban-opt11-strips': 'sokoban',
'spider-opt18-strips': 'spider',
'storage': 'storage', # identity
'termes-opt18-strips': 'termes',
'tetris-opt14-strips': 'tetris',
'tidybot-opt11-strips': 'tidybot',
'tidybot-opt14-strips': 'tidybot',
'tpp': 'tpp', # identity
'transport-opt08-strips': 'transport',
'transport-opt11-strips': 'transport',
'transport-opt14-strips': 'transport',
'trucks': 'trucks', # identity
'trucks-strips': 'trucks',
'visitall-opt11-strips': 'visitall',
'visitall-opt14-strips': 'visitall',
'woodworking-opt08-strips': 'woodworking',
'woodworking-opt11-strips': 'woodworking',
'zenotravel': 'zenotravel', # identity
}

def domain_as_category(run1, run2):
    return run1['domain']

# "Exp 1": plain algorithms, old vs new

# for pruning percentage
exp.add_report(
    AbsoluteReport(
        # attributes=['coverage'],
        attributes=html_table_attributes,
        format='html',
        filter_algorithm=[
            'blind',
            'blind-simple-min0.0',
            'blind-queue-fast_downward-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'blind-pruning.html'),
)

# for producing data below
exp.add_report(
    DifferentCoverageDomainReport(
        attributes=['coverage'], # does not matter
        format='tex',
        filter_algorithm=[
            'blind',
            'blind-simple-min0.0',
            'blind-queue-fast_downward-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'blind-coverage-different-domains.tex'),
)

# for producing data below
exp.add_report(
    DifferentCoverageDomainReport(
        attributes=['coverage'], # does not matter
        format='tex',
        filter_algorithm=[
            'lmcut',
            'lmcut-simple-min0.0',
            'lmcut-queue-fast_downward-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'lmcut-coverage-different-domains.tex'),
)

# for producing data below
exp.add_report(
    DifferentCoverageDomainReport(
        attributes=['coverage'], # does not matter
        format='tex',
        filter_algorithm=[
            'scp',
            'scp-simple-min0.0',
            'scp-queue-fast_downward-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'scp-coverage-different-domains.tex'),
)

# output of above reports
affected_domains_blind = set(['airport', 'data-network-opt18-strips',
'freecell', 'hiking-opt14-strips', 'miconic', 'mprime',
'nomystery-opt11-strips', 'openstacks-opt08-strips', 'openstacks-opt11-strips',
'organic-synthesis-split-opt18-strips', 'parcprinter-08-strips',
'parcprinter-opt11-strips', 'petri-net-alignment-opt18-strips',
'pipesworld-notankage', 'pipesworld-tankage', 'rovers', 'scanalyzer-08-strips',
'scanalyzer-opt11-strips', 'snake-opt18-strips', 'spider-opt18-strips',
'termes-opt18-strips', 'tetris-opt14-strips', 'tidybot-opt11-strips',
'tidybot-opt14-strips', 'transport-opt14-strips', 'trucks-strips',
'woodworking-opt08-strips', 'woodworking-opt11-strips', 'zenotravel'])

affected_domains_lmcut = set(['nomystery-opt11-strips',
'openstacks-opt08-strips', 'openstacks-opt11-strips',
'organic-synthesis-split-opt18-strips', 'parcprinter-08-strips',
'parcprinter-opt11-strips', 'parking-opt14-strips', 'pegsol-08-strips',
'pegsol-opt11-strips', 'rovers', 'satellite', 'scanalyzer-08-strips',
'scanalyzer-opt11-strips', 'snake-opt18-strips', 'termes-opt18-strips',
'tetris-opt14-strips', 'tidybot-opt14-strips', 'woodworking-opt08-strips',
'woodworking-opt11-strips'])

affected_domains_scp = set(['data-network-opt18-strips', 'freecell',
'hiking-opt14-strips', 'miconic', 'mprime', 'openstacks-opt08-strips',
'openstacks-opt11-strips', 'organic-synthesis-split-opt18-strips',
'parcprinter-08-strips', 'parcprinter-opt11-strips', 'parking-opt11-strips',
'parking-opt14-strips', 'pipesworld-tankage', 'rovers', 'satellite',
'scanalyzer-08-strips', 'scanalyzer-opt11-strips', 'snake-opt18-strips',
'spider-opt18-strips', 'termes-opt18-strips', 'tetris-opt14-strips',
'tidybot-opt11-strips', 'tidybot-opt14-strips', 'transport-opt11-strips',
'transport-opt14-strips', 'woodworking-opt08-strips',
'woodworking-opt11-strips'])

# part of Table 2 in the paper
exp.add_report(
    AbsoluteReport(
        attributes=['coverage'],
        format='tex',
        filter_algorithm=[
            'blind',
            'blind-simple-min0.0',
            'blind-queue-fast_downward-min0.0',
        ],
        filter_domain=sorted(affected_domains_blind | affected_domains_lmcut | affected_domains_scp),
    ),
    outfile=os.path.join(exp.eval_dir, 'blind-coverage.tex'),
)

# part of Table 2 in the paper
exp.add_report(
    AbsoluteReport(
        attributes=['coverage'],
        format='tex',
        filter_algorithm=[
            'lmcut',
            'lmcut-simple-min0.0',
            'lmcut-queue-fast_downward-min0.0',
        ],
        filter_domain=sorted(affected_domains_blind | affected_domains_lmcut | affected_domains_scp),
    ),
    outfile=os.path.join(exp.eval_dir, 'lmcut-coverage.tex'),
)

# part of Table 2 in the paper
exp.add_report(
    AbsoluteReport(
        attributes=['coverage'],
        format='tex',
        filter_algorithm=[
            'scp',
            'scp-simple-min0.0',
            'scp-queue-fast_downward-min0.0',
        ],
        filter_domain=sorted(affected_domains_blind | affected_domains_lmcut | affected_domains_scp),
    ),
    outfile=os.path.join(exp.eval_dir, 'scp-coverage.tex'),
)

# part of Table 2 in the paper (summary)
exp.add_report(
    AbsoluteReport(
        attributes=['coverage'],
        format='tex',
        filter_algorithm=[
            'blind',
            'blind-simple-min0.0',
            'blind-queue-fast_downward-min0.0',
            'lmcut',
            'lmcut-simple-min0.0',
            'lmcut-queue-fast_downward-min0.0',
            'scp',
            'scp-simple-min0.0',
            'scp-queue-fast_downward-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'all-coverage.tex'),
)

# not shown in the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_time'],
        format='tex',
        filter_algorithm=[
            'blind-simple-min0.0',
            'blind-queue-fast_downward-min0.0',
        ],
        # get_category=domain_as_category,
        show_missing=False,
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-blind-pruning-time-simple-vs-queue'),
)

# not shown in the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_time'],
        format='tex',
        filter_algorithm=[
            'lmcut-simple-min0.0',
            'lmcut-queue-fast_downward-min0.0',
        ],
        # get_category=domain_as_category,
        show_missing=False,
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-lmcut-pruning-time-simple-vs-queue'),
)

# Figure 2 in the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_time'],
        format='tex',
        filter_algorithm=[
            'scp-simple-min0.0',
            'scp-queue-fast_downward-min0.0',
        ],
        # get_category=domain_as_category,
        show_missing=False,
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-scp-pruning-time-simple-vs-queue'),
)

# "Exp 2": enhancements for action-centric

# not part of the paper, but used in the text
exp.add_report(
    DifferentCoverageDomainReport(
        attributes=['coverage'], # does not matter
        format='tex',
        filter_algorithm=[
            'blind-queue-dynamic_small-min0.0',
            'blind-queue-dynamic_small-mark-min0.0',
            'blind-queue-static_small-min0.0',
            'blind-queue-static_small-mark-min0.0',
            'blind-queue-fast_downward-min0.0',
            'blind-queue-fast_downward-mark-min0.0',
            'blind-queue-minimize_ss-min0.0',
            'blind-queue-minimize_ss-mark-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'blind-queue-coverage.tex'),
)

# not part of the paper, but used in the text
exp.add_report(
    DifferentCoverageDomainReport(
        attributes=['coverage'], # does not matter
        format='tex',
        filter_algorithm=[
            'lmcut-queue-dynamic_small-min0.0',
            'lmcut-queue-dynamic_small-mark-min0.0',
            'lmcut-queue-static_small-min0.0',
            'lmcut-queue-static_small-mark-min0.0',
            'lmcut-queue-fast_downward-min0.0',
            'lmcut-queue-fast_downward-mark-min0.0',
            'lmcut-queue-minimize_ss-min0.0',
            'lmcut-queue-minimize_ss-mark-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'lmcut-queue-coverage.tex'),
)

# Table 3 in the paper
exp.add_report(
    DifferentCoverageDomainReport(
        attributes=['coverage'], # does not matter
        format='tex',
        filter_algorithm=[
            'scp-queue-dynamic_small-min0.0',
            'scp-queue-dynamic_small-mark-min0.0',
            'scp-queue-static_small-min0.0',
            'scp-queue-static_small-mark-min0.0',
            'scp-queue-fast_downward-min0.0',
            'scp-queue-fast_downward-mark-min0.0',
            'scp-queue-minimize_ss-min0.0',
            'scp-queue-minimize_ss-mark-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'scp-queue-coverage.tex'),
)

# not shown in the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_ratio'],
        format='tex',
        filter=[filter_unsolvable_tasks],
        filter_algorithm=[
            'blind-queue-fast_downward-min0.0',
            'blind-queue-minimize_ss-min0.0',
        ],
        show_missing=False,
        scale='linear',
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-blind-pruning-ratio-queue-fast_downward-vs-queue-minimize_ss'),
)

# not shown in the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_ratio'],
        format='tex',
        filter=[filter_unsolvable_tasks],
        filter_algorithm=[
            'lmcut-queue-fast_downward-min0.0',
            'lmcut-queue-minimize_ss-min0.0',
        ],
        # get_category=interesting_domains_as_category,
        show_missing=False,
        scale='linear',
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-lmcut-pruning-ratio-queue-fast_downward-vs-queue-minimize_ss'),
)

scp_interesting_domains = [
'elevators',
'logistics',
'movie',
'mystery', # not interesting for LM-cut
'openstacks',
'parcprinter',
'psr-small',
'rovers',
'satellite',
'woodworking',
]

def interesting_domains_as_category(run1, run2):
    grouped_domain = domain_groups_optimal[run1['domain']]
    if grouped_domain in scp_interesting_domains:
        return grouped_domain
    return ''

# Figure 3 in the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_ratio'],
        format='tex',
        filter=[filter_unsolvable_tasks],
        filter_algorithm=[
            'scp-queue-fast_downward-min0.0',
            'scp-queue-minimize_ss-min0.0',
        ],
        get_category=interesting_domains_as_category,
        show_missing=False,
        scale='linear',
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-scp-pruning-ratio-queue-fast_downward-vs-queue-minimize_ss'),
)

# "Exp 3": comparison against state of the art

# not part of the paper (but used for text)
exp.add_report(
    AbsoluteReport(
        attributes=latex_table_attributes,
        format='tex',
        filter_algorithm=[
            'blind-ec-mutex-min0.0',
            'blind-queue-minimize_ss-mark-min0.0',
            'lmcut-ec-mutex-min0.0',
            'lmcut-queue-minimize_ss-mark-min0.0',
            'scp-ec-mutex-min0.0',
            'scp-queue-minimize_ss-mark-min0.0',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'ec-mutex-vs-queue-minimize_ss-mark-abs.tex'),
)

# not part of the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_ratio'],
        format='tex',
        filter=[filter_unsolvable_tasks],
        filter_algorithm=[
            'blind-ec-mutex-min0.0',
            'blind-queue-minimize_ss-mark-min0.0',
        ],
        show_missing=False,
        scale='linear',
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-blind-pruning-ratio-ec-mutex-vs-queue-minimize_ss-mark'),
)

# not part of the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_time'],
        format='tex',
        filter=[filter_unsolvable_tasks],
        filter_algorithm=[
            'blind-ec-mutex-min0.0',
            'blind-queue-minimize_ss-mark-min0.0',
        ],
        show_missing=False,
        scale='linear',
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-blind-pruning-time-ec-mutex-vs-queue-minimize_ss-mark'),
)

# not part of the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_ratio'],
        format='tex',
        filter=[filter_unsolvable_tasks],
        filter_algorithm=[
            'lmcut-ec-mutex-min0.0',
            'lmcut-queue-minimize_ss-mark-min0.0',
        ],
        show_missing=False,
        scale='linear',
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-lmcut-pruning-ratio-ec-mutex-vs-queue-minimize_ss-mark'),
)

# not part of the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_time'],
        format='tex',
        filter=[filter_unsolvable_tasks],
        filter_algorithm=[
            'lmcut-ec-mutex-min0.0',
            'lmcut-queue-minimize_ss-mark-min0.0',
        ],
        show_missing=False,
        scale='linear',
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-lmcut-pruning-time-ec-mutex-vs-queue-minimize_ss-mark'),
)

# Figure 4 in the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_ratio'],
        format='tex',
        filter=[filter_unsolvable_tasks],
        filter_algorithm=[
            'scp-ec-mutex-min0.0',
            'scp-queue-minimize_ss-mark-min0.0',
        ],
        show_missing=False,
        scale='linear',
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-scp-pruning-ratio-ec-mutex-vs-queue-minimize_ss-mark'),
)

# Figure 4 in the paper
exp.add_report(
    ScatterPlotReport(
        attributes=['ss_pruning_time'],
        format='tex',
        filter=[filter_unsolvable_tasks],
        filter_algorithm=[
            'scp-ec-mutex-min0.0',
            'scp-queue-minimize_ss-mark-min0.0',
        ],
        show_missing=False,
        scale='linear',
    ),
    outfile=os.path.join(exp.eval_dir, 'scatter-scp-pruning-time-ec-mutex-vs-queue-minimize_ss-mark'),
)

# not part of the paper
exp.add_report(
    DifferentCoverageDomainReport(
        attributes=['coverage'], # does not matter
        format='tex',
        filter_algorithm=[
            'blind',
            'blind-ec-mutex-min0.0',
            'blind-queue-minimize_ss-mark-min0.0',
            'blind-ec-mutex-min0.2',
            'blind-queue-minimize_ss-mark-min0.2',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'blind-ec-mutex-vs-queue-minimize_ss-mark-coverage.tex'),
)

# not part of the paper
exp.add_report(
    DifferentCoverageDomainReport(
        attributes=['coverage'], # does not matter
        format='tex',
        filter_algorithm=[
            'lmcut',
            'lmcut-ec-mutex-min0.0',
            'lmcut-queue-minimize_ss-mark-min0.0',
            'lmcut-ec-mutex-min0.2',
            'lmcut-queue-minimize_ss-mark-min0.2',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'lmcut-ec-mutex-vs-queue-minimize_ss-mark-coverage.tex'),
)

# not part of the paper (but used for text in Discussion and Future Work)
exp.add_report(
    DifferentCoverageDomainReport(
        attributes=['coverage'], # does not matter
        format='tex',
        filter_algorithm=[
            'scp',
            'scp-ec-mutex-min0.0',
            'scp-queue-minimize_ss-mark-min0.0',
            'scp-ec-mutex-min0.2',
            'scp-queue-minimize_ss-mark-min0.2',
        ],
    ),
    outfile=os.path.join(exp.eval_dir, 'scp-ec-mutex-vs-queue-minimize_ss-mark-coverage.tex'),
)

exp.run_steps()
