#! /usr/bin/env python

from collections import defaultdict, Counter
import os.path
import subprocess
import sys

from downward.reports.absolute import AbsoluteReport
from downward.reports.compare import ComparativeReport
import lab
from lab.reports import Attribute, geometric_mean

FILE = os.path.abspath(__file__)
DIR = os.path.dirname(FILE)
sys.path.insert(0, os.path.dirname(DIR))

import project

# Create custom report class with suitable info and error attributes.
class BaseReport(AbsoluteReport):
    INFO_ATTRIBUTES = []
    ERROR_ATTRIBUTES = [
        'domain', 'problem', 'algorithm', 'unexplained_errors', 'error', 'node']


FILENAME = os.path.splitext(os.path.basename(__file__))[0]
EXPS = os.path.join(DIR, "data")
EXPPATH = os.path.join(EXPS, FILENAME)

ATTRIBUTES = [
    'error',
    'run_dir',
    'coverage',
    # 'search_time',
    'total_time',
    'score_total_time',
    'generated',
    'expansions_until_last_jump',
    # Attribute("ss_successors_unpruned", absolute=True, min_wins=True),
    # Attribute("ss_successors_pruned", absolute=True, min_wins=True),
    Attribute("ss_pruning_ratio", absolute=True, min_wins=False),
    Attribute("ss_pruning_time", absolute=False, min_wins=True, function=geometric_mean),
]

exp = lab.experiment.Experiment()
exp.steps = []
exp.add_step(
    "remove-combined-properties",
    project.remove_file,
    os.path.join(exp.eval_dir, "properties"))

project.fetch_algorithms(
    exp, "2020-02-12-B-scp")
project.fetch_algorithms(
    exp, "2020-02-12-C-scp-min-pruning")

CONFIGS = [
    "sss-scp-v1-scp-ec",
    "sss-scp-v1-scp-ec-mutex",
    "sss-scp-v1-scp-ec-wss",
    "sss-scp-v1-scp-queue-mark",
    "sss-scp-v1-scp-queue-mark-minss",
    "sss-scp-v1-scp-queue",
    "sss-scp-v1-scp-queue-minss",
    "sss-scp-v1-scp-queue-wss-mark",
    "sss-scp-v1-scp-queue-wss-mark-minss",
    "sss-scp-v1-scp-queue-wss",
    "sss-scp-v1-scp-queue-wss-minss",
    "sss-scp-v1-scp-simple",
    "sss-scp-v1-scp-simple-mutex",
    "sss-scp-v1-scp-simple-wss",
]

report = os.path.join(exp.eval_dir, '{}.html'.format(exp.name))
exp.add_report(
    ComparativeReport(
        attributes=ATTRIBUTES,
        format='html',
        algorithm_pairs=[
            (config, config + '-min0.2') for config in CONFIGS
        ],
    ),
    outfile=report)
exp.add_step('open-report', subprocess.call, ['xdg-open', report])
exp.add_step('publish-report', subprocess.call, ['publish', report])

exp.run_steps()
